@@ -183,7 +183,7 @@ describe 'keystone' do
       end
 
       it { is_expected.to contain_exec('restart_keystone').with(
-        'command' => "service #{platform_params[:httpd_service_name]} restart",
+        'command' => "systemctl restart #{platform_params[:httpd_service_name]}",
       ) }
     end
 
@@ -197,17 +197,10 @@ describe 'keystone' do
 
     context 'with disabled service managing' do
       let :params do
-        { :manage_service => false,
-          :enabled        => false }
+        { :manage_service => false }
       end
 
-      it { is_expected.to contain_service('keystone').with(
-        'ensure'     => nil,
-        'enable'     => false,
-        'hasstatus'  => true,
-        'hasrestart' => true
-      ) }
-      it { is_expected.to contain_anchor('keystone::service::end') }
+      it { is_expected.to_not contain_service('keystone') }
     end
 
     context 'with invalid catalog_type' do
@@ -538,7 +531,7 @@ describe 'keystone' do
       end
 
       it { is_expected.to contain_exec('restart_keystone').with(
-        'command' => "service #{platform_params[:service_name]} restart",
+        'command' => "systemctl restart #{platform_params[:service_name]}",
       ) }
       it { is_expected.to contain_anchor('default_domain_created') }
     end
@@ -634,7 +627,7 @@ describe 'keystone' do
       let (:facts) do
         facts.merge!(OSDefaults.get_facts({
           :concat_basedir => '/var/lib/puppet/concat',
-          :fqdn           => 'some.host.tld'
+          :fqdn           => 'some.host.tld',
         }))
       end
 
